
# Type: expressed in


holds between a gene or gene product and an anatomical entity in which it is expressed

URI: [biolink:expressed_in](https://w3id.org/biolink/vocab/expressed_in)


## Domain and Range

[GeneOrGeneProduct](GeneOrGeneProduct.md) ->  <sub>0..*</sub> [AnatomicalEntity](AnatomicalEntity.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children


## Used by

 * [RNAProduct](RNAProduct.md)
 * [RNAProductIsoform](RNAProductIsoform.md)
 * [Gene](Gene.md)
 * [GeneOrGeneProduct](GeneOrGeneProduct.md)
 * [GeneProduct](GeneProduct.md)
 * [GeneProductIsoform](GeneProductIsoform.md)
 * [MicroRNA](MicroRNA.md)
 * [NoncodingRNAProduct](NoncodingRNAProduct.md)
 * [Protein](Protein.md)
 * [ProteinIsoform](ProteinIsoform.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | RO:0002206 |
| **In Subsets:** | | translator_minimal |

